Coverage for manage.py: 100%

# Coverage for manage.py : 100%

## 6 statements 6 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1#!/usr/bin/env python

2 import os

3 import sys

4

5 if __name__ == "__main__":

6 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "project.settings")

7

8 from django.core.management import execute_from_command_line

9

10 execute_from_command_line(sys.argv)